@@ -77,6 +77,24 @@ private Q_SLOTS:
         QVERIFY(job.data().contains("@context"));
     }
 
+    void testOsmNode()
+    {
+        m_nam.requests.clear();
+        m_nam.replies.push({QNetworkReply::NoError, 200, QByteArray("<osm version=\"0.6\"><node id=\"448814556\" lat=\"52.5135789\" lon=\"13.4184810\"><tag k=\"addr:city\" v=\"Berlin\"/><tag k=\"addr:country\" v=\"DE\"/><tag k=\"addr:housenumber\" v=\"6\"/><tag k=\"addr:postcode\" v=\"10179\"/><tag k=\"addr:street\" v=\"Brückenstraße\"/><tag k=\"addr:suburb\" v=\"Mitte\"/><tag k=\"amenity\" v=\"restaurant\"/><tag k=\"contact:website\" v=\"http://www.ming-dynastie.de\"/><tag k=\"cuisine\" v=\"chinese\"/><tag k=\"name\" v=\"Ming Dynastie\"/></node></osm>"), QString()});
+
+        DownloadJob job(QUrl(QStringLiteral("https://www.openstreetmap.org/node/448814556")), &m_nam);
+        QSignalSpy finishedSpy(&job, &DownloadJob::finished);
+        QVERIFY(finishedSpy.wait());
+
+        QCOMPARE(m_nam.requests.size(), 1);
+        QCOMPARE(m_nam.requests[0].op, QNetworkAccessManager::GetOperation);
+        QCOMPARE(m_nam.requests[0].request.url(), QUrl(QStringLiteral("https://www.openstreetmap.org/api/0.6/node/448814556")));
+
+        QCOMPARE(job.hasError(), false);
+        QCOMPARE(job.errorMessage(), QString());
+        QVERIFY(job.data().contains("@context"));
+    }
+
     void test404()
     {
         m_nam.requests.clear();
