@@ -4,9 +4,9 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <kandroidextras/androidtypes.h>
-#include <kandroidextras/jnisignature.h>
-#include <kandroidextras/javatypes.h>
+#include "kandroidextras/androidtypes.h"
+#include "kandroidextras/jnisignature.h"
+#include "kandroidextras/javatypes.h"
 
 #include <QtTest/qtest.h>
 
