@@ -8,6 +8,7 @@
 
 #include "timelinedelegatecontroller.h"
 #include "applicationcontroller.h"
+#include "importcontroller.h"
 #include "livedatamanager.h"
 #include "reservationmanager.h"
 #include "transfermanager.h"
@@ -28,6 +29,7 @@
 #include <QStandardPaths>
 #include <QTimeZone>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace KItinerary;
 
 class TimelineDelegateControllerTest : public QObject
@@ -87,6 +89,11 @@ private Q_SLOTS:
         TrainTrip trip;
         trip.setTrainNumber(QStringLiteral("TGV 1235"));
         trip.setDepartureTime(QDateTime::currentDateTime().addDays(-1));
+        TrainStation station;
+        station.setName(u"Brussels"_s);
+        trip.setDepartureStation(station);
+        station.setName(u"Paris"_s);
+        trip.setArrivalStation(station);
         TrainReservation res;
         res.setReservationNumber(QStringLiteral("XXX007"));
         res.setReservationFor(trip);
@@ -128,6 +135,11 @@ private Q_SLOTS:
             TrainTrip trip;
             trip.setTrainNumber(QStringLiteral("TGV 1235"));
             trip.setDepartureTime(QDateTime::currentDateTime().addDays(2));
+            TrainStation station;
+            station.setName(u"Brussels"_s);
+            trip.setDepartureStation(station);
+            station.setName(u"Paris"_s);
+            trip.setArrivalStation(station);
             TrainReservation res;
             res.setReservationNumber(QStringLiteral("XXX007"));
             res.setReservationFor(trip);
@@ -140,12 +152,15 @@ private Q_SLOTS:
         controller.setBatchId(batchId);
         QCOMPARE(controller.previousLocation(), QVariant());
 
+        TrainStation depStation;
+        depStation.setName(u"Somewhere Else"_s);
         TrainStation arrStation;
         arrStation.setName(QStringLiteral("My Station"));
         TrainTrip prevTrip;
         prevTrip.setTrainNumber(QStringLiteral("ICE 1234"));
         prevTrip.setDepartureTime(QDateTime::currentDateTime().addDays(1));
         prevTrip.setArrivalTime(QDateTime::currentDateTime().addDays(1));
+        prevTrip.setDepartureStation(depStation);
         prevTrip.setArrivalStation(arrStation);
         TrainReservation prevRes;
         prevRes.setReservationNumber(QStringLiteral("XXX007"));
@@ -168,7 +183,10 @@ private Q_SLOTS:
         ldm.setPkPassManager(&pkPassMgr);
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&mgr);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
+        ImportController importer;
+        importer.setReservationManager(&mgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
+        ctrl->commitImport(&importer);
 
         TimelineDelegateController controller;
         controller.setReservationManager(&mgr);
@@ -212,7 +230,10 @@ private Q_SLOTS:
         ldm.setReservationManager(&mgr);
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&mgr);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
+        ImportController importer;
+        importer.setReservationManager(&mgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
+        ctrl->commitImport(&importer);
 
         TimelineDelegateController controller;
         controller.setReservationManager(&mgr);
@@ -254,7 +275,10 @@ private Q_SLOTS:
         Test::clearAll(&mgr);
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&mgr);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/timeline/flight-cancelation.json")));
+        ImportController importer;
+        importer.setReservationManager(&mgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/timeline/flight-cancelation.json")));
+        ctrl->commitImport(&importer);
 
         TimelineDelegateController controller;
         controller.setReservationManager(&mgr);
@@ -275,7 +299,10 @@ private Q_SLOTS:
         TransferManager trfMgr;
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&mgr);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
+        ImportController importer;
+        importer.setReservationManager(&mgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
+        ctrl->commitImport(&importer);
 
         TimelineDelegateController controller;
         controller.setReservationManager(&mgr);
@@ -405,7 +432,8 @@ private Q_SLOTS:
 
         // single static element, see 44ed4fbe96d45a60b33e2bf784196489197d7dcc
         Test::clearAll(&mgr);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/haus-randa-v1.json")));
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/haus-randa-v1.json")));
+        ctrl->commitImport(&importer);
         QCOMPARE(mgr.batches().size(), 1);
         controller.setBatchId(mgr.batches().at(0));
         args = controller.mapArguments().toVariant().toMap();
