@@ -9,6 +9,7 @@
 
 #include "applicationcontroller.h"
 #include "favoritelocationmodel.h"
+#include "importcontroller.h"
 #include "livedatamanager.h"
 #include "locationinformation.h"
 #include "pkpassmanager.h"
@@ -32,6 +33,8 @@
 #include <QSignalSpy>
 #include <QStandardPaths>
 
+using namespace Qt::Literals::StringLiterals;
+
 void initLocale()
 {
     qputenv("LC_ALL", "en_US.utf-8");
@@ -110,7 +113,10 @@ private Q_SLOTS:
 
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/boardingpass-v1.pkpass")));
+        ImportController importer;
+        importer.setReservationManager(&resMgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/boardingpass-v1.pkpass")));
+        ctrl->commitImport(&importer);
         QCOMPARE(insertSpy.size(), 2);
         QCOMPARE(insertSpy.at(0).at(1).toInt(), 0);
         QCOMPARE(insertSpy.at(0).at(2).toInt(), 0);
@@ -123,7 +129,8 @@ private Q_SLOTS:
         insertSpy.clear();
         updateSpy.clear();
         rmSpy.clear();
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/boardingpass-v2.pkpass")));
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/boardingpass-v2.pkpass")));
+        ctrl->commitImport(&importer);
         QCOMPARE(insertSpy.size(), 1);
         QCOMPARE(updateSpy.size(), 1);
         QCOMPARE(updateSpy.at(0).at(0).toModelIndex().row(), 0);
@@ -161,7 +168,10 @@ private Q_SLOTS:
 
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/haus-randa-v1.json")));
+        ImportController importer;
+        importer.setReservationManager(&resMgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/haus-randa-v1.json")));
+        ctrl->commitImport(&importer);
         QCOMPARE(insertSpy.size(), 4);
         QCOMPARE(insertSpy.at(0).at(1).toInt(), 0);
         QCOMPARE(insertSpy.at(0).at(2).toInt(), 0);
@@ -179,7 +189,8 @@ private Q_SLOTS:
         insertSpy.clear();
         updateSpy.clear();
         rmSpy.clear();
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/haus-randa-v2.json")));
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/haus-randa-v2.json")));
+        ctrl->commitImport(&importer);
         QCOMPARE(insertSpy.size(), 3);
         QCOMPARE(updateSpy.size(), 1);
         QCOMPARE(rmSpy.size(), 3);
@@ -217,7 +228,10 @@ private Q_SLOTS:
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
 
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
+        ImportController importer;
+        importer.setReservationManager(&resMgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
+        ctrl->commitImport(&importer);
         QCOMPARE(model.rowCount(), 6); //  2x country info, 2x flights, today marker, 1x DST info
 
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
@@ -274,10 +288,14 @@ private Q_SLOTS:
         geo.setLatitude(52.0f);
         geo.setLongitude(13.0f);
         Airport a;
+        a.setName(u"Berlin"_s);
         a.setGeo(geo);
         Flight f;
         f.setArrivalAirport(a);
         f.setDepartureTime(QDateTime(QDate(2018, 1, 1), QTime(0, 0)));
+        a.setName(u"Zurich"_s);
+        a.setGeo({});
+        f.setDepartureAirport(a);
         FlightReservation res;
         res.setReservationFor(f);
         resMgr.addReservation(res);
@@ -424,9 +442,13 @@ private Q_SLOTS:
         model.setReservationManager(&resMgr);
         model.setWeatherForecastManager(&weatherMgr);
 
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/weather-no-location-change.json")));
+        ImportController importer;
+        importer.setReservationManager(&resMgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/weather-no-location-change.json")));
+        ctrl->commitImport(&importer);
         ModelVerificationPoint vp0(QLatin1StringView(SOURCE_DIR "/data/weather-no-location-change.model"));
         vp0.setRoleFilter({TimelineModel::BatchIdRole});
+        vp0.setJsonPropertyFilter({"elements"_L1});
         QVERIFY(vp0.verify(&model));
     }
 
@@ -452,26 +474,30 @@ private Q_SLOTS:
         QVERIFY(rmSpy.isValid());
 
         // full import at runtime
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
-        QCOMPARE(model.rowCount(), 4); // 2x Flight, 1x DST info, 1x TodayMarker
-        QCOMPARE(updateSpy.count(), 2);
-        QCOMPARE(updateSpy.count(), 2);
+        ImportController importer;
+        importer.setReservationManager(&resMgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
+        ctrl->commitImport(&importer);
+        QCOMPARE(model.rowCount(), 5); // 2x Flight, 1x tz change info, 1x DST info, 1x TodayMarker
+        QCOMPARE(updateSpy.count(), 3);
         QCOMPARE(rmSpy.count(), 3);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
         QCOMPARE(model.index(1, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
         QCOMPARE(model.index(2, 0).data(TimelineModel::ElementTypeRole), TimelineElement::LocationInfo);
-        QCOMPARE(model.index(3, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
+        QCOMPARE(model.index(3, 0).data(TimelineModel::ElementTypeRole), TimelineElement::LocationInfo);
+        QCOMPARE(model.index(4, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
         QCOMPARE(resMgr.reservationsForBatch(model.index(0, 0).data(TimelineModel::BatchIdRole).toString()).size(), 2);
         QCOMPARE(resMgr.reservationsForBatch(model.index(1, 0).data(TimelineModel::BatchIdRole).toString()).size(), 2);
 
         // already existing data
         model.setReservationManager(nullptr);
         model.setReservationManager(&resMgr);
-        QCOMPARE(model.rowCount(), 4); // 2x Flight, 1x DST info, 1x TodayMarger
+        QCOMPARE(model.rowCount(), 5); // 2x Flight, 1x tz change, 1x DST info, 1x TodayMarger
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
         QCOMPARE(model.index(1, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
         QCOMPARE(model.index(2, 0).data(TimelineModel::ElementTypeRole), TimelineElement::LocationInfo);
-        QCOMPARE(model.index(3, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
+        QCOMPARE(model.index(3, 0).data(TimelineModel::ElementTypeRole), TimelineElement::LocationInfo);
+        QCOMPARE(model.index(4, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
         QCOMPARE(resMgr.reservationsForBatch(model.index(0, 0).data(TimelineModel::BatchIdRole).toString()).size(), 2);
         QCOMPARE(resMgr.reservationsForBatch(model.index(1, 0).data(TimelineModel::BatchIdRole).toString()).size(), 2);
 
@@ -486,8 +512,8 @@ private Q_SLOTS:
         flight.setDepartureTime(flight.departureTime().addDays(1));
         res.setReservationFor(flight);
         resMgr.updateReservation(resId, res);
-        QCOMPARE(model.rowCount(), 5);
-        QCOMPARE(updateSpy.count(), 1);
+        QCOMPARE(model.rowCount(), 6);
+        QCOMPARE(updateSpy.count(), 2);
         QCOMPARE(insertSpy.count(), 2);
         QCOMPARE(rmSpy.count(), 1);
 
@@ -498,8 +524,8 @@ private Q_SLOTS:
         flight.setDepartureTime(flight.departureTime().addDays(-1));
         res.setReservationFor(flight);
         resMgr.updateReservation(resId, res);
-        QCOMPARE(model.rowCount(), 4);
-        QCOMPARE(updateSpy.count(), 1);
+        QCOMPARE(model.rowCount(), 5);
+        QCOMPARE(updateSpy.count(), 3);
         QCOMPARE(rmSpy.count(), 3);
         QCOMPARE(insertSpy.count(), 2);
 
@@ -508,8 +534,8 @@ private Q_SLOTS:
         rmSpy.clear();
         Test::clearAll(&resMgr);
         QCOMPARE(model.rowCount(), 1);
-        QCOMPARE(rmSpy.count(), 6);
-        QCOMPARE(updateSpy.count(), 2);
+        QCOMPARE(rmSpy.count(), 7);
+        QCOMPARE(updateSpy.count(), 3);
     }
 
     void testDayChange()
@@ -530,24 +556,31 @@ private Q_SLOTS:
 
         ModelVerificationPoint vp0(QLatin1StringView(SOURCE_DIR "/data/timeline/daychange-r0.model"));
         vp0.setRoleFilter({TimelineModel::BatchIdRole});
+        vp0.setJsonPropertyFilter({"elements"_L1});
         QVERIFY(vp0.verify(&model));
 
         // changing the day should move the today marker
         model.setCurrentDateTime(QDateTime({2196, 10, 15}, {0, 15}));
         ModelVerificationPoint vp1(QLatin1StringView(SOURCE_DIR "/data/timeline/daychange-r1.model"));
         vp1.setRoleFilter({TimelineModel::BatchIdRole});
+        vp1.setJsonPropertyFilter({"elements"_L1});
         QVERIFY(vp1.verify(&model));
 
         // load something to define the current location, so we get weather
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
+        ImportController importer;
+        importer.setReservationManager(&resMgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
+        ctrl->commitImport(&importer);
         ModelVerificationPoint vp2(QLatin1StringView(SOURCE_DIR "/data/timeline/daychange-r2.model"));
         vp2.setRoleFilter({TimelineModel::BatchIdRole});
+        vp2.setJsonPropertyFilter({"elements"_L1});
         QVERIFY(vp2.verify(&model));
 
         // changing the day should move the today marker and weather one day forward
         model.setCurrentDateTime(QDateTime({2196, 10, 16}, {19, 30}));
         ModelVerificationPoint vp3(QLatin1StringView(SOURCE_DIR "/data/timeline/daychange-r3.model"));
         vp3.setRoleFilter({TimelineModel::BatchIdRole});
+        vp3.setJsonPropertyFilter({"elements"_L1});
         QVERIFY(vp3.verify(&model));
     }
 
@@ -570,9 +603,10 @@ private Q_SLOTS:
         Test::clearAll(&resMgr);
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&resMgr);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/timeline/") + baseName + QLatin1StringView(".json")));
-        TripGroupManager groupMgr;
-        groupMgr.setReservationManager(&resMgr);
+        ImportController importer;
+        importer.setReservationManager(&resMgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/timeline/") + baseName + QLatin1StringView(".json")));
+        ctrl->commitImport(&importer);
         WeatherForecastManager weatherMgr;
         weatherMgr.setTestModeEnabled(true);
 
@@ -593,10 +627,13 @@ private Q_SLOTS:
         TransferManager transferMgr;
         transferMgr.overrideCurrentDateTime(QDateTime({1996, 10, 14}, {12, 34}));
         transferMgr.setReservationManager(&resMgr);
-        transferMgr.setTripGroupManager(&groupMgr);
         transferMgr.setFavoriteLocationModel(&favLocModel);
         transferMgr.setLiveDataManager(&liveMgr);
 
+        TripGroupManager groupMgr;
+        groupMgr.setReservationManager(&resMgr);
+        groupMgr.setTransferManager(&transferMgr);
+
         TimelineModel model;
         QAbstractItemModelTester tester(&model);
         model.setHomeCountryIsoCode(QStringLiteral("DE"));
@@ -609,12 +646,13 @@ private Q_SLOTS:
         // check state is correct for data imported at the start
         ModelVerificationPoint vp(QLatin1StringView(SOURCE_DIR "/data/timeline/") + baseName + QLatin1StringView(".model"));
         vp.setRoleFilter({TimelineModel::BatchIdRole, TimelineModel::TripGroupIdRole});
-        vp.setJsonPropertyFilter({QStringLiteral("reservationId")});
+        vp.setJsonPropertyFilter({"reservationId"_L1, "elements"_L1});
         QVERIFY(vp.verify(&model));
 
         // retry with loading during runtime
         Test::clearAll(&resMgr);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/timeline/") + baseName + QLatin1StringView(".json")));
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/timeline/") + baseName + QLatin1StringView(".json")));
+        ctrl->commitImport(&importer);
         QVERIFY(vp.verify(&model));
     }
 
@@ -632,7 +670,10 @@ private Q_SLOTS:
 
         QSignalSpy currentResChangedSpy(&model, &TimelineModel::currentBatchChanged);
 
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
+        ImportController importer;
+        importer.setReservationManager(&resMgr);
+        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
+        ctrl->commitImport(&importer);
         QCOMPARE(model.rowCount(), 14);
         QVERIFY(!currentResChangedSpy.empty());
 
