@@ -16,13 +16,13 @@
 #include <QStandardPaths>
 
 #ifdef Q_OS_ANDROID
-#include <kandroidextras/contentresolver.h>
-#include <kandroidextras/javatypes.h>
-#include <kandroidextras/jnisignature.h>
-#include <kandroidextras/manifestpermission.h>
+#include "kandroidextras/contentresolver.h"
+#include "kandroidextras/javatypes.h"
+#include "kandroidextras/jnisignature.h"
+#include "kandroidextras/manifestpermission.h"
 using namespace KAndroidExtras;
 
-#include <private/qandroidextras_p.h>
+#include "private/qandroidextras_p.h"
 #endif
 
 #include <csignal>
@@ -44,7 +44,7 @@ void DevelopmentModeController::enablePublicTransportLogging()
 #else
     const auto baseDir = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
 #endif
-    qputenv("KPUBLICTRANSPORT_LOG_DIR", (baseDir + QLatin1String("/kpublictransport-log")).toUtf8());
+    qputenv("KPUBLICTRANSPORT_LOG_DIR", (baseDir + QLatin1StringView("/kpublictransport-log")).toUtf8());
 }
 
 void DevelopmentModeController::importMapCSS(const QUrl &url)
@@ -58,7 +58,7 @@ void DevelopmentModeController::importMapCSS(const QUrl &url)
     const auto fileName = KAndroidExtras::ContentResolver::fileName(url);
     auto dest = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
 #endif
-    dest += QLatin1String("/org.kde.kosmindoormap/assets/css/");
+    dest += QLatin1StringView("/org.kde.kosmindoormap/assets/css/");
 
     qDebug() << "importing mapcss" << url << dest << fileName;
     QDir().mkpath(dest);
@@ -72,7 +72,7 @@ void DevelopmentModeController::purgeMapCSS()
 #else
     QString path = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
 #endif
-    path += QLatin1String("/org.kde.kosmindoormap/assets/css/");
+    path += QLatin1StringView("/org.kde.kosmindoormap/assets/css/");
     QDir(path).removeRecursively();
 }
 
@@ -82,11 +82,11 @@ void DevelopmentModeController::clearOsmTileCache()
     QString base;
     if (!qEnvironmentVariableIsSet("KOSMINDOORMAP_CACHE_PATH")) {
         base = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation)
-            + QLatin1String("/org.kde.osm/vectorosm");
+            + QLatin1StringView("/org.kde.osm/vectorosm");
     } else {
         base = qEnvironmentVariable("KOSMINDOORMAP_CACHE_PATH");
     }
-    QDir(base + QLatin1String("/17")).removeRecursively();
+    QDir(base + QLatin1StringView("/17")).removeRecursively();
 }
 
 void DevelopmentModeController::crash()
@@ -100,12 +100,12 @@ QString DevelopmentModeController::screenInfo()
     const auto screens = QGuiApplication::screens();
     for (auto screen : screens) {
         info += screen->name() + QLatin1Char(' ') + screen->model() + QLatin1Char(' ') + screen->serialNumber() + QLatin1Char('\n');
-        info += QLatin1String("size: ") + QString::number(screen->size().width()) + QLatin1Char('x') + QString::number(screen->size().height()) + QLatin1Char('\n');
-        info += QLatin1String("virtual size: ") + QString::number(screen->virtualSize().width()) + QLatin1Char('x') + QString::number(screen->virtualSize().height()) + QLatin1Char('\n');
-        info += QLatin1String("physical size: ") + QString::number(screen->physicalSize().width()) + QLatin1Char('x') + QString::number(screen->physicalSize().height()) + QLatin1Char('\n');
-        info += QLatin1String("logical DPI: ") + QString::number(screen->logicalDotsPerInchX())  + QLatin1Char('x') + QString::number(screen->logicalDotsPerInchY()) + QLatin1Char('\n');
-        info += QLatin1String("physical DPI: ") + QString::number(screen->physicalDotsPerInchX())  + QLatin1Char('x') + QString::number(screen->physicalDotsPerInchY()) + QLatin1Char('\n');
-        info += QLatin1String("device pixel ratio: ") + QString::number(screen->devicePixelRatio()) + QLatin1Char('\n');
+        info += QLatin1StringView("size: ") + QString::number(screen->size().width()) + QLatin1Char('x') + QString::number(screen->size().height()) + QLatin1Char('\n');
+        info += QLatin1StringView("virtual size: ") + QString::number(screen->virtualSize().width()) + QLatin1Char('x') + QString::number(screen->virtualSize().height()) + QLatin1Char('\n');
+        info += QLatin1StringView("physical size: ") + QString::number(screen->physicalSize().width()) + QLatin1Char('x') + QString::number(screen->physicalSize().height()) + QLatin1Char('\n');
+        info += QLatin1StringView("logical DPI: ") + QString::number(screen->logicalDotsPerInchX())  + QLatin1Char('x') + QString::number(screen->logicalDotsPerInchY()) + QLatin1Char('\n');
+        info += QLatin1StringView("physical DPI: ") + QString::number(screen->physicalDotsPerInchX())  + QLatin1Char('x') + QString::number(screen->physicalDotsPerInchY()) + QLatin1Char('\n');
+        info += QLatin1StringView("device pixel ratio: ") + QString::number(screen->devicePixelRatio()) + QLatin1Char('\n');
         info += QLatin1Char('\n');
     }
     return info;
