@@ -15,8 +15,9 @@
 
 #include <KOSMIndoorMap/Platform>
 
-#include <KPublicTransport/Location>
 #include <KPublicTransport/Line>
+#include <KPublicTransport/Load>
+#include <KPublicTransport/Location>
 #include <KPublicTransport/Manager>
 
 #include <QGeoCoordinate>
@@ -80,24 +81,6 @@ public:
     static bool isBusMode(KPublicTransport::Line::Mode mode);
     static bool isBoatMode(KPublicTransport::Line::Mode mode);
 
-    /** Provide an icon source for usage in Kirigami.Icon that represents the line mode.
-     *  This can be an official line logo, and official product logo or a generic mode icon,
-     *  depending on what's available.
-     *  @note line/product logos are full-color, the generic ones are monochrome colorable Breeze icons.
-     */
-    Q_INVOKABLE QString lineIcon(const QVariant &line) const;
-
-    /** Convert a KPublicTransport::Line::Mode enum value to an icon source or name
-     *  for usage in Kirigami.Icon.
-     */
-    Q_INVOKABLE QString lineModeIcon(int lineMode) const;
-
-    /** Provides an icon for a rental vehicle type. */
-    Q_INVOKABLE QString rentalVehicleIcon(const KPublicTransport::RentalVehicle &vehicle) const;
-
-    /** Provide an icon source for usage in Kirigami.Icon that represents @p journeySection. */
-    Q_INVOKABLE QString journeySectionIcon(const KPublicTransport::JourneySection &journeySection) const;
-
     /** Provide a label that represents @p journeySection. */
     Q_INVOKABLE QString journeySectionLabel(const KPublicTransport::JourneySection &journeySection) const;
 
@@ -136,6 +119,9 @@ public:
      */
     Q_INVOKABLE [[nodiscard]] static QList<QGeoCoordinate> pathToGeoCoordinates(const KPublicTransport::JourneySection &jny);
 
+    /** Returns the maximum occupancy found in the given load information set. */
+    Q_INVOKABLE [[nodiscard]] static KPublicTransport::Load::Category maximumOccupancy(const QList<KPublicTransport::LoadInfo> &loadInfo);
+
 private:
     // for use by the template code
     static QString idenfitierFromLocation(const KPublicTransport::Location &loc);
